import React, { useCallback, useMemo } from 'react'
import { useModel } from 'umi'
import { Tree } from 'antd'
import { FolderFilled, FolderOpenFilled } from '@ant-design/icons'
import { NodeTitle } from './node-title'
import styles from './index.less'
import { componentsData, applicationTemplate } from './componentTreeNodes'

const { DirectoryTree, TreeNode } = Tree

const FolderIcon = ({ expanded }: { expanded: boolean }) => {
  return expanded ? <FolderOpenFilled /> : <FolderFilled />
}

export const CategoryTree = () => {
  const { componentApplications } = useModel('guide-algo-component')

  const renderTree = useCallback(
    (treeList: any[] = [], searchKey: string = '') => {
      return treeList.map((item) => {
        const { isDir, id, children } = item
        const key = id.toString();
        const title = <NodeTitle node={item} searchKey={searchKey} />

        if (isDir) {
          return (
            <TreeNode
              icon={FolderIcon}
              key={key}
              title={title}
              className={styles.treeFolder}
            >
              {renderTree(children, searchKey)}
            </TreeNode>
          )
        }

        return (
          <TreeNode
            isLeaf={true}
            key={key}
            icon={<span />}
            title={title}
            className={styles.treeNode}
          />
        )
      })
    },
    [],
  )

  const applicationsTreeData = useMemo(() => {
    // 根据模板生成应用组件数据格式
    const applicationsData = componentApplications?.map(applicationTemplate /* 模板方法 */);
    return componentApplications?.map(applicationTemplate);
  }, [componentApplications])

  // console.log('componentsData', componentsData, renderTree(componentsData))

  return (
    <div className={styles.list}>
      <DirectoryTree
        showIcon={true}
        selectable={false}
        defaultExpandAll
        className={styles.tree}
      >
        {renderTree(componentsData)}
      </DirectoryTree>
    </div>
  )
}
